---
title: "Knative steering committee"
linkTitle: "Steering committee"
weight: 40
type: "docs"
---

The Knative Steering Committee (KSC) is the ultimate authority for the Knative
project, and governs all aspects of the project.

The governance of Knative is an open, living document, and will continue to
evolve as the community and project change. We expect over time we will adapt
the way we run this committee, based on feedback from the community.

- [Charter](#charter)
- [Delegated authority](#delegated-authority)
- [Committee Meetings](#committee-meetings)
- [Committee Mechanics](#committee-mechanics)
- [Committee Members](#committee-members)
  - [Allocation of seats](#allocation-of-seats)
- [Decision process](#decision-process)
- [Changes to the charter](#changes-to-the-charter)
- [Getting in touch](#getting-in-touch)

## Charter

1. Define, evolve, and promote the vision, values, mission, and scope of the project.
1. Define and evolve project governance structures and policies, including
   project roles and how collaborators become members, approvers, leads,
   and/or administrators. This includes policy for the creation and
   administration of [working groups](./WORKING-GROUPS.md) and committees.
1. Steward, control access, delegate access, and establishes processes regarding,
   all Knative project resources and has the final say in the disposition of
   those resources.
1. Manage the Knative brand and decide which things can be called "Knative" and
   how that mark can be used in relation to other efforts or vendors.
1. Confirm/reject nominations to the KSC from organizations who are allocated seats.
1. Confirm/reject nominations to the Technical Oversight Committee.
1. Receive and handle reports about [code of conduct](./CODE-OF-CONDUCT.md)
   violations and maintain confidentiality.
1. Receive security reports; work with the appropriate technical leads to
   accept or reject the report; maintain the private nature of such reports
   until disclosed to the broader community.
1. Act as the final escalation point and decider for any disputes, issues,
   clarifications, or escalations within the project scope.

## Delegated authority

KSC may choose to delegate its authority to other committees as-needed. The
committee currently recognizes this delegated authority for:

- Technical guidance is delegated to the [Technical Oversight Committee](./TECH-OVERSIGHT-COMMITTEE.md).

## Committee Meetings

KSC meets every two weeks, or as-needed. Meetings are held online.

Given the private nature of many of these discussions (e.g. privacy, private
emails to the committee, code of conduct violations, escalations, disputes
between members, security reports, etc.) meetings are held in private.

Meeting notes are available to members of the knative-dev mailing list
(link to be added).

Questions and proposals for changes to governance are posted as issues in the
[docs repo](https://github.com/knative/docs), and the KSC invites your feedback
there. See [Getting in touch](#getting-in-touch) for other options.

## Committee members

Seats on the Steering Committee are held by an organization, not by the
individual.

The committee was created as the project was in its infancy, in order to
tackle governance and overall project strategy. Because of the nature of the
project and funding required, it was decided that strong corporate leadership
was necessary for the project to ensure velocity. As the project grows and
matures the KSC will, from time to time, consider if this policy should be
changed.

The current membership of the committee is currently (listed alphabetically by name):

| &nbsp;                                                   | Member         | Organization | Profile                                  |
| -------------------------------------------------------- | -------------- | ------------ | ---------------------------------------- |
| <img width="30px" src="https://github.com/dewitt.png">   | DeWitt Clinton | Google       | [@dewitt](https://github.com/dewitt)     |
| <img width="30px" src="https://github.com/mchmarny.png"> | Mark Chmarny   | Google       | [@mchmarny](https://github.com/mchmarny) |
| <img width="30px" src="https://github.com/isdal.png">    | Tomas Isdal    | Google       | [@isdal](https://github.com/isdal)       |
|   | TBD | Google   |        |
|   | TBD | IBM      |        |
|   | TBD | Pivotal  |        |
|   | TBD | Red Hat  |        |

There are currently four unfilled seats, as indicated by TBD.

### Allocation of seats

Seats on the steering committee are allocated based upon contribution
to the project by an organization. No final decision has been made on the exact
formula.

As the project continues to grow, we expect to add additional seats to the
committee, ensuring that those contributing to the project are properly
represented.

- After a seat is allocated to an organization, the organization shall nominate
  a candidate to be confirmed by KSC. The committee reserves the right to not
  confirm a candidate, in which the organization would need to nominate a new
  candidate
- Members of the committee may step down at any time. When a member steps down,
  their organization shall nominate a new candidate.
- If a member leaves their organization, the organization must nominate a new
  committee member to replace them following the nomination and confirmation
  process.
- If an organization is unable to seat a candidate, the KSC reserves the right
  to reallocate the seat to another organization.
- Changes to the number of seats, which company seats are allocated to, and
  nominations to the committee are confirmed by majority vote of the committee
  members.
- In situations where the organization which holds a seat is no longer a viable
  entity (e.g. merger, dissolution, bankruptcy) the KSC will make a decision on
  how to reallocate that seat. Seats do not automatically transfer to any
  organization.
- Members on the committee have a 1 year term from their confirmation, and may
  be reconfirmed to the committee at the end of their term.

## Decision process

The steering committee desires to always reach consensus.

Decisions are made in meetings when a quorum of the members are present and may
pass with majority of the committee supporting it.

Quorum is considered reached when at least half of the members are present.

In case of extended absence, the organization of the absent member may appoint
a single delegate from the same company during the absence.

## Changes to the charter

Changes to the KSC charter may be proposed via a Pull Request on the charter
itself. Amendments are accepted with majority consent of the committee.

Proposals and amendments to the charter are available for at least a period of
one week for comments and questions before a vote will occur.

## Getting in touch

If you'd like to reach out to the committee, please drop a note
to [knative-steering@googlegroups.com](mailto:knative-steering@googlegroups.com).
This is a private discussion list to which all members of the committee have access.

---

Portions of this document are adapted from the
[Istio Steering Committee](https://github.com/istio/community/blob/master/STEERING-COMMITTEE.md)
documentation, which is licensed under the Apache License 2.0.

Except as otherwise noted, the content of this page is licensed under the
[Creative Commons Attribution 4.0 License](https://creativecommons.org/licenses/by/4.0/),
and code samples are licensed under the
[Apache 2.0 License](https://www.apache.org/licenses/LICENSE-2.0).
